@@ -1,7 +1,7 @@
 """
 Type annotations for personalize-runtime service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/type_defs.html)
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -26,17 +26,29 @@ __all__ = (
     "PredictedItemTypeDef",
 )
 
+GetPersonalizedRankingResponseTypeDef = TypedDict(
+    "GetPersonalizedRankingResponseTypeDef",
+    {
+        "personalizedRanking": List["PredictedItemTypeDef"],
+        "recommendationId": str,
+    },
+    total=False,
+)
 
-class GetPersonalizedRankingResponseTypeDef(TypedDict, total=False):
-    personalizedRanking: List["PredictedItemTypeDef"]
-    recommendationId: str
+GetRecommendationsResponseTypeDef = TypedDict(
+    "GetRecommendationsResponseTypeDef",
+    {
+        "itemList": List["PredictedItemTypeDef"],
+        "recommendationId": str,
+    },
+    total=False,
+)
 
-
-class GetRecommendationsResponseTypeDef(TypedDict, total=False):
-    itemList: List["PredictedItemTypeDef"]
-    recommendationId: str
-
-
-class PredictedItemTypeDef(TypedDict, total=False):
-    itemId: str
-    score: float
+PredictedItemTypeDef = TypedDict(
+    "PredictedItemTypeDef",
+    {
+        "itemId": str,
+        "score": float,
+    },
+    total=False,
+)
